
function love.load()

	love.window.setMode(800,800)
	love.physics.setMeter(10)
	love.window.setTitle("Block Physics Testbed")

	world = love.physics.newWorld(0,0,true)

	midx = 200
	midy = 400

	world:setCallbacks(beginContact,endContact,preSolve,postSolve)

	length = 20

	blocks = {}
	blocks[0] = {}
	blocks[0].shape = love.physics.newRectangleShape(20,20)
	blocks[0].body = love.physics.newBody(world,midx,midy, "dynamic")
	blocks[0].fixture = love.physics.newFixture(blocks[0].body,blocks[0].shape,1)
	blocks[0].fixture:setFriction(10)
	blocks[0].fixture:setRestitution(0.2)
	for i=1, length do
		blocks[i] = {}
		blocks[i].shape = love.physics.newRectangleShape(20,20)
		blocks[i].body = love.physics.newBody(world,midx+20*i,midy, "dynamic")
		blocks[i].fixture = love.physics.newFixture(blocks[i].body,blocks[i].shape,1)
		blocks[i].fixture:setFriction(10)
		blocks[i].fixture:setRestitution(1)
		blocks[i].body:setLinearDamping(0)
		blocks[i].body:setAngularDamping(0)
		--blocks[i].joint = love.physics.newWeldJoint(blocks[i].body,blocks[i-1].body,midx+20*i,midy+10,true)
		--blocks[i].jointTop = love.physics.newRopeJoint(blocks[i-1].body,blocks[i].body,blocks[i-1].body:getX(),blocks[i-1].body:getY()-10,blocks[i].body:getX(),blocks[i].body:getY()-10,10,true)
		--blocks[i].jointBot = love.physics.newRopeJoint(blocks[i-1].body,blocks[i].body,blocks[i-1].body:getX(),blocks[i-1].body:getY()+10,blocks[i].body:getX(),blocks[i].body:getY()+10,20,true)
		blocks[i].jointTop = love.physics.newWeldJoint(blocks[i-1].body, blocks[i].body, blocks[i].body:getX()-10, blocks[i].body:getY(), true)
		--blocks[i].jointBot = love.physics.newRevoluteJoint(blocks[i-1].body, blocks[i].body, blocks[i].body:getX()-10, blocks[i].body:getY()+10, true)
		--blocks[i].jointTop = love.physics.newRevoluteJoint(blocks[i-1].body, blocks[i].body, blocks[i].body:getX()-10, blocks[i].body:getY(), true)
		--blocks[i].joint:setDampingRatio(0.1)
		--blocks[i].jointTop:setFrequency(10)

	end

	mweight = {}
	mweight.shape = love.physics.newCircleShape(20)
	mweight.body = love.physics.newBody(world,midx+20*(length+2),midy-300, "dynamic")
	mweight.fixture = love.physics.newFixture(mweight.body,mweight.shape,2)
	mweight.fixture:setRestitution(1)
	mweight.body:setLinearDamping(0)
	mweight.body:setAngularDamping(0)
	mweight.body:applyLinearImpulse(-800,2000)


	--jdamp = blocks[1].joint:getDampingRatio()
	--jfreq = blocks[1].joint:getFrequency()
	ts = 0
end

function beginContact()

end

function endContact()
end

function preSolve()
end

function postSolve()
end

function love.update(dt)

	world:update(dt)

	for i=1, length do
		if blocks[i].jointTop:isDestroyed() == false then
			fx, fy = blocks[i].jointTop:getReactionForce(1/dt)
			forc = ((fx^2)+(fy^2))^0.5
			if forc>8000 then
				blocks[i].jointTop:destroy()
			end
		end
		--[[if blocks[i].jointBot:isDestroyed() == false then
							fx, fy = blocks[i].jointBot:getReactionForce(1/dt)
							forc = ((fx^2)+(fy^2))^0.5
							if forc>15000 then
								blocks[i].jointBot:destroy()
							end
						end]]
	end
	ts = dt

end

function draw_background()
	love.graphics.setColor(128,64,64,64)
end

function draw_block(id)
	love.graphics.setColor(255,0,0)
	love.graphics.translate(blocks[id].body:getX(),blocks[id].body:getY())
	love.graphics.rotate(blocks[id].body:getAngle())
	love.graphics.translate(-blocks[id].body:getX(),-blocks[id].body:getY())
	love.graphics.rectangle("line",blocks[id].body:getX()-10,blocks[id].body:getY()-10,20,20)
	love.graphics.origin()
	if id~=0 then
		if blocks[id].jointTop:isDestroyed() == false then
			fx, fy = blocks[id].jointTop:getReactionForce(1/ts)
			forc = ((fx^2)+(fy^2))^0.5
			forc = tonumber(string.format("%.0f", forc))
			love.graphics.print(forc,blocks[id].body:getX()-20,blocks[id].body:getY()-30-6*((-1)^id))
		end
	end
	--[[if id~=0 then
				if blocks[id].jointBot:isDestroyed() == false then
					fx, fy = blocks[id].jointBot:getReactionForce(1/ts)
					forc = ((fx^2)+(fy^2))^0.5
					forc = tonumber(string.format("%.1f", forc))
					love.graphics.print(forc,blocks[id].body:getX()-20,blocks[id].body:getY()+40-6*((-1)^id))
				end
			end]]
end

function draw_weight()
	love.graphics.setColor(255,0,0)
	love.graphics.circle("line", mweight.body:getX(), mweight.body:getY(), 20, 32)
end

function love.draw()
	draw_background()
	draw_weight()
	for i=0, length do
		draw_block(i)
	end


	--love.graphics.print(jdamp,100,100)
	--love.graphics.print(jfreq,200,100)


end
